/**********************************************************
 *  Systemy Mikroprocesorowe w Sterowaniu,  WEiTI PW 			*
 *  STM3210E-EVAL:  PROJEKT_17 arytmetyka stalopozycyjna	*
 **********************************************************/
#include "stm32f10x.h"
#include "stm3210e_eval_lcd.h"
#include "AsmQ32.h"
#include <stdio.h>
#include <math.h>
#define Brown 0xEBC2
#define Amber 0xFDEA
const float pi = 3.14159265;
const float e  = 2.7182818;

// zmienne globalne -------------------------------------------
uint8_t str2disp[] = {"                    \0"};
const int N = sizeof(str2disp) - 1;

// prototypy funkcji ------------------------------------------
int  RCC_Config(void);
void GPIO_Config(void);
void Delay(unsigned int);
int Q1516_sin(int);
float sine(float);

// main -------------------------------------------------------
int main(void) {
  unsigned int i, j=0x00500000;  // j = 80
	int x, y;
	float xf, yf;
	
  //konfiguracja systemu --------------------------------------
  RCC_Config();		
  GPIO_Config(); 
  GPIO_ResetBits(GPIOF, GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9);	// zgasimy wszystkie diody LED
  STM3210E_LCD_Init();	// inicjalizacja TFT LCD 240320L8
	LCD_Clear(Black);			// Clear the LCD
	
	// napis ----------------------------------------------------
  LCD_SetBackColor(Black);		// kolor tla
  LCD_SetTextColor(Amber);		// kolor textu
	LCD_SetFont(&Font16x24);
	LCD_DisplayStringLine(Line0, (uint8_t *)"Projekt17_Q1516_sin ");
	LCD_SetTextColor(Yellow);

  for(i=0; i<320; i++){
		x = Q1516_mult(j, 0x00000506);
		j = Q32_add(j, 0x00010000);
/*
		LCD_Clear(Black);			// Clear the LCD
		xf = Q1516_float(x);
		sprintf((char *)str2disp," x = %f",xf);
		LCD_DisplayStringLine(Line2, (uint8_t *)str2disp);
		yf = sine(xf);
		sprintf((char *)str2disp,"sine(x)= %f",yf);
		LCD_DisplayStringLine(Line6, (uint8_t *)str2disp);
		y = Q1516_sin(x);
		yf = Q1516_float(y);
		sprintf((char *)str2disp,"sin(x) = %f",yf);
		LCD_DisplayStringLine(Line8, (uint8_t *)str2disp);
		Delay(8000000);	
*/

		y = Q1516_sin(x);
		y = Q1516_mult(0x00640000, y);
		y = Q32_add(y, 0x00820000);
		y = Q1516_int(y);
		LCD_DrawUniLine((uint16_t) y, (uint16_t) 319-i, (uint16_t) y, (uint16_t) 319-i);
	}
  LCD_SetTextColor(Red);
	LCD_DrawUniLine(130,320,130,0);
	
	xf = pi/4;
	x = float_Q1516(xf);
	
	//testy szybkosci dzialan arytmetycznych --------------------
	while (1) {
		// testy dodawania -----------------------
		xf = e/100;
		x = float_Q1516(xf);
		yf = 0; y = 0;
		GPIO_WriteBit(GPIOF, GPIO_Pin_7, Bit_SET);
		GPIO_WriteBit(GPIOF, GPIO_Pin_8, Bit_SET);
		for(i=0; i<1000000; i++)
			y = Q32_add(y,x);			// Q15.16
		GPIO_WriteBit(GPIOF, GPIO_Pin_7, Bit_RESET);
		GPIO_WriteBit(GPIOF, GPIO_Pin_8, Bit_RESET);
		
		GPIO_WriteBit(GPIOF, GPIO_Pin_6, Bit_SET);
		GPIO_WriteBit(GPIOF, GPIO_Pin_9, Bit_SET);
		for(i=0; i<1000000; i++)
			yf = yf + xf;			// float
		GPIO_WriteBit(GPIOF, GPIO_Pin_6, Bit_RESET);
		GPIO_WriteBit(GPIOF, GPIO_Pin_9, Bit_RESET);
		
		sprintf((char *)str2disp,"yf = %f",yf);
		LCD_DisplayStringLine(Line9, (uint8_t *)str2disp);
		yf = Q1516_float(y);
		sprintf((char *)str2disp,"y  = %f",yf);
		LCD_DisplayStringLine(Line8, (uint8_t *)str2disp);
	}
}
//------------ konfiguracja RCC: sygnaly taktujace ------------
int RCC_Config(void) {
  ErrorStatus HSEStartUpStatus;                          // zmienna opisujaca rezultat uruchomienia HSE

  RCC_DeInit();                                          // RCC na 'default reset state'
  RCC_HSEConfig(RCC_HSE_ON);                             // wlacz HSE
  HSEStartUpStatus = RCC_WaitForHSEStartUp();            // czekaj na gotowosc HSE
  if(HSEStartUpStatus == SUCCESS) {
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);//
    FLASH_SetLatency(FLASH_Latency_2);                   // zwloka Flasha: 2 takty dla 72MHz
    RCC_HCLKConfig(RCC_SYSCLK_Div1);                     // HCLK=SYSCLK
    RCC_PCLK2Config(RCC_HCLK_Div1);                      // PCLK2=HCLK
    RCC_PCLK1Config(RCC_HCLK_Div2);                      // PCLK1=HCLK/2
    RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9); // PLLCLK = HSE*9 czyli 8MHz * 9 = 72 MHz
    RCC_PLLCmd(ENABLE);                                  // wlacz PLL
    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);  // czekaj na uruchomienie PLL
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);           // ustaw PLL jako zrodlo sygnalu zegarowego
    while(RCC_GetSYSCLKSource() != 0x08);                // czekaj az PLL bedzie sygnalem zegarowym systemu
// konfiguracja sygnalow taktujacych uzywanych peryferii 
    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOF, ENABLE);// wlacz taktowanie portu GPIO F
		return 0;
  }
	else
		return 1;
}
//------------------ konfiguracja portow GPIO -----------------
void GPIO_Config(void) {
  GPIO_InitTypeDef  GPIO_InitStructure; 

  /*Tu nalezy umiescic kod zwiazany z konfiguracja poszczegolnych portow GPIO potrzebnych w programie*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;      // wyjscie w trybie push-pull
  GPIO_Init(GPIOF, &GPIO_InitStructure);
}
//-------------------------------------------------------------
void Delay(unsigned int counter){
	// opoznienie programowe, 8'000'000 to jedna sekunda
	while (counter--){
		__NOP();
		__NOP();
	}
}
// sinf	sinus float -------------------------------------------
float sinf(float x){
	float ret = 0.0;
	float	pow	=	x;
	float	term = pow;
	float	sign = 1.0;
	float	fact = 1.0;
	int k = 1;
	
	while(fabs(term) >= 0.00001f){
		term	=	sign*pow/fact;
		ret	+= term;
		pow *= x*x;
		fact *= 2*k * (2*k+1);
		sign = 0 - sign;
		k++;
	}
	return ret;
}		
// Q1516_sin	sinus stalopozycyjny Q1516 ----------------------
// liczby: 	pi/2 = 0x00019220;
//					2*pi = 0x0006487F;
int Q1516_sin(int x){
	int	minus = 0x00010000;
	int	quarter = 0;
	int ret, pow, term, sign, fact, k2, k21, k;
	
	if(x < 0){
		x = Q32_neg(x);				// sin(-x) = - sin(x)
		minus = Q32_neg(minus);
	}
	while(x > 0x0006487F)		// 2*pi
		x -= 0x0006487F;
	// numer cwiartki
	while(x > 0x00019220){	// pi/2
		x -= 0x00019220;
		quarter++;
	}
		switch(quarter){
		case 1:	x = Q32_sub(0x00019220, x);
						break;
		case 2:	minus = Q32_neg(minus);
						break;
		case 3:	x = Q32_sub(0x00019220, x);
						minus = Q32_neg(minus);
	}
	// liczymy sin(x) w pierwszej cwiartce
	ret = 0;
	pow	=	x;
	term = pow;
	sign = 0x00010000;
	fact = 0x00010000;
	k = 0x00010000;	
	while(Q32_abs(term) >= 0x00000080){
		term = Q1516_div(pow, fact);
		term = Q1516_mult(sign, term);		// term	=	sign*pow/fact;
		ret = Q32_add(ret, term);					// ret	+= term;
		pow = Q1516_mult(pow, x);
		pow = Q1516_mult(pow, x);					// pow *= x*x;
		k2 = Q1516_mult(k, 0x00020000);
		k21 = Q32_add(k2, 0x00010000);
		fact = Q1516_mult(fact, k2);
		fact = Q1516_mult(fact, k21);			// fact *= 2*k * (2*k+1);
		sign = Q32_neg(sign);
		k = Q32_add(k, 0x00010000);				// k++;
	}
	return Q1516_mult(ret, minus);
}

/**************** (C) COPYRIGHT 2016 PLUMicroelectronics *****END OF FILE******/



