/******************************************************
 *  Systemy Mikroprocesorowe w Sterowaniu,  WEiTI PW 	*
 *  STM3210E-EVAL: PROJEKT_22 rejestracja temperatury	*
 *       gniazdo BNC-CN3 -> PC2 wejscie analogowe			*
 *			 										Pt100 + DMA rejestracja		*
 ******************************************************/
#include "stm32f10x.h"
#include "stm3210e_eval_lcd.h"
#include <stdio.h>

int  RCC_Config(void);
void GPIO_Config(void);
void NVIC_Config(void);
void DMA_Config(void);
void ADC_Config(void);
int SysTick_Config_Div8(unsigned int Ticks);
void Delay(unsigned int);

// zmienne globalne -------------------------------------------
unsigned char txt2LCD[32] = {0}; 	// bufor funkcji sprintf
uint16_t PC2_adc[100]={0};				// bufor na wartosci binarne z ADC

int main(void) {
  //------------------- deklaracje zmiennych ------------------
  float current, T, x;
	unsigned int i, y;
	
  //konfiguracja systemu --------------------------------------
  RCC_Config();		
  GPIO_Config();
	NVIC_Config();
	DMA_Config();
	ADC_Config();						// inicjalizacja ADC1
	STM3210E_LCD_Init();		// inicjalizacja TFT LCD 240320L8
  GPIO_ResetBits(GPIOF, GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9);	// zgasimy wszystkie diody LED
	LCD_Clear(Black);		// Clear the LCD
  LCD_SetBackColor(Black);		// kolor tla
	LCD_SetFont(&Font16x24);
	SysTick_Config_Div8(900000ul);	// przerwanie co 0.1 sekundy
	
	label:
  for(y=0; y<320; y++){
		current =0.0;
		for(i=0; i<100; i++){
			current += (float)PC2_adc[i] * 0.00667904;		// przeliczone na prad [mA]
		}
		current /= 100.0;
		
		T = 5.625*current - 52.5;
		LCD_SetTextColor(Green);   // kolor textu
		txt2LCD[31] = 0x00;
		snprintf((char *)txt2LCD,31,"  T = %3.2f  ['C]    ",T);
		LCD_DisplayStringLine(Line8, (uint8_t *)txt2LCD);
		LCD_SetTextColor(Blue);   // kolor textu
		snprintf((char *)txt2LCD,31,"CN3 = %3.3f [mA]    ",current);
		LCD_DisplayStringLine(Line9, (uint8_t *)txt2LCD);
		LCD_SetTextColor(Black);   // kasujemy poprzedni punkt
		LCD_DrawLine(0, 319-y, 192, LCD_DIR_VERTICAL);
		LCD_SetTextColor(Green);   // kolor linii
		
		x = -20*T + 640;
		if(x < 0.0)
			x = 0.0;
		else if(x > 319.0)
			x = 319.0;
		LCD_DrawLine((int)x, 319-y, 1, LCD_DIR_HORIZONTAL);

		Delay(1000000);

  }
	goto label;
}
//------------ konfiguracja RCC: sygnaly taktujace ------------
int RCC_Config(void) {
  ErrorStatus HSEStartUpStatus;                          // zmienna opisujaca rezultat uruchomienia HSE

  RCC_DeInit();                                          // RCC na 'default reset state'
  RCC_HSEConfig(RCC_HSE_ON);                             // wlacz HSE
  HSEStartUpStatus = RCC_WaitForHSEStartUp();            // czekaj na gotowosc HSE
  if(HSEStartUpStatus == SUCCESS) {
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);//
    FLASH_SetLatency(FLASH_Latency_2);                   // zwloka Flasha: 2 takty dla 72MHz
    RCC_HCLKConfig(RCC_SYSCLK_Div1);                     // HCLK=SYSCLK
    RCC_PCLK2Config(RCC_HCLK_Div1);                      // PCLK2=HCLK
    RCC_PCLK1Config(RCC_HCLK_Div2);                      // PCLK1=HCLK/2
    RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9); // PLLCLK = HSE*9 czyli 8MHz * 9 = 72 MHz
    RCC_PLLCmd(ENABLE);                                  // wlacz PLL
    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);  // czekaj na uruchomienie PLL
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);           // ustaw PLL jako zrodlo sygnalu zegarowego
    while(RCC_GetSYSCLKSource() != 0x08);                // czekaj az PLL bedzie sygnalem zegarowym systemu
// konfiguracja sygnalow taktujacych uzywanych peryferii
		RCC_ADCCLKConfig(RCC_PCLK2_Div6);                    // ADCCLK = PCLK2/6 = 72 MHz /6 = 12 MHz
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1, ENABLE); // wlacz taktowanie ADC1
		RCC_AHBPeriphClockCmd(RCC_AHBPeriph_DMA1, ENABLE);   //wlacz taktowanie DMA
    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOF, ENABLE);// port GPIO F : LEDy
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);// port GPIO C : PC2 = wejscie analogowe
		return 0;
  }
	else
		return 1;
}
//------------------ konfiguracja portow GPIO -----------------
void GPIO_Config(void) {
  GPIO_InitTypeDef  GPIO_InitStructure; 

  /*Tu nalezy umiescic kod zwiazany z konfiguracja poszczegolnych portow GPIO potrzebnych w programie*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;      // wyjscie w trybie push-pull
  GPIO_Init(GPIOF, &GPIO_InitStructure);
	
	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_2;						//	wejscie analogowe:
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;					// 		z gniazda BNC-CN3 -> PC2
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);
}
// ----------- konfiguracja kontrolera przerwan NVIC ----------
void NVIC_Config(void) {
  NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);   
}
// --------- konfiguracja licznika systemowego SysTick --------
int SysTick_Config_Div8(unsigned int Ticks){ 
  unsigned int ctrl;

  if (Ticks > SysTick_LOAD_RELOAD_Msk)  return 1;             	// czy wartosc poczatkowa nie przekracza max
                                                                
  SysTick->LOAD = (Ticks & SysTick_LOAD_RELOAD_Msk) - 1;        // ustaw wartosc poczatkowa licznika 
  NVIC_SetPriority (SysTick_IRQn, 0);                           // ustaw priorytet przerwania
  SysTick->VAL  = 0;                                            // ustaw wartosc aktualna licznika
  ctrl=SysTick_CTRL_TICKINT_Msk | SysTick_CTRL_ENABLE_Msk;      // ustaw flagi wlaczenia SysTick IRQ  i samego licznika
	ctrl &= SysTick_CLKSource_HCLK_Div8;
  SysTick->CTRL = ctrl;                  // zapisz ustawienia do rejestru sterujacego SysTick (i wlacz licznik)
  return 0;
}
// -------------- konfiguracja przetwornika ADC1 --------------
void ADC_Config(void){
  ADC_InitTypeDef ADC_InitStructure;
	  
	ADC_InitStructure.ADC_Mode = ADC_Mode_Independent;                  // praca niezalezna
	ADC_InitStructure.ADC_ScanConvMode = DISABLE;                       // pomiar jednego kanalu, skanowanie kanalow nie potrzebne
  ADC_InitStructure.ADC_ContinuousConvMode = DISABLE;               	// pomiar w trybie jednokrotnym
  //ADC_InitStructure.ADC_ContinuousConvMode = ENABLE;                // pomiar w trybie ciaglym
	ADC_InitStructure.ADC_ExternalTrigConv = ADC_ExternalTrigConv_None;	// brak wyzwalania zewnetrznego
	ADC_InitStructure.ADC_DataAlign = ADC_DataAlign_Right;            	// wyrownanie danych do prawej - 12 mlodszych bitow znaczacych
	ADC_InitStructure.ADC_NbrOfChannel = 1; 	                          // liczba uzywanych kanalow =1
	ADC_Init(ADC1, &ADC_InitStructure);                                 // incjalizacja przetwornika ADC1
	ADC_Cmd(ADC1, ENABLE);                                              // wlacz ADC1
	
	ADC_ResetCalibration(ADC1);                                         // reset rejestrow kalibracyjnych ADC1
	while(ADC_GetResetCalibrationStatus(ADC1));                         // czekamy na wykonanie resetu
	ADC_StartCalibration(ADC1);                                         // kalibracja ADC1
	while(ADC_GetCalibrationStatus(ADC1));                              // czekamy na zakonczenie kalibracji ADC1

	ADC_RegularChannelConfig(ADC1, ADC_Channel_12, 1, ADC_SampleTime_1Cycles5); 
                                                                      // kanal 12 - GPIO-PC2 - BNC-CN3
                                                                      // grupa podstawowa, czas probkowania 1,5 + 12,5 = 14 cykli
	ADC_DMACmd(ADC1,ENABLE); 	                                          // wlaczenie DMA dla ADC1
}
// ----------------- konfiguracja kanalu DMA ------------------
void DMA_Config(void){
  #define ADC1_DR_Address 0x4001244C;                                             //adres rejestru ADC1->DR
  DMA_InitTypeDef DMA_InitStructure;
	
  DMA_DeInit(DMA1_Channel1);                                                  // usun ewentualna poprzednia konfiguracje DMA
  DMA_InitStructure.DMA_PeripheralBaseAddr = (uint32_t)ADC1_DR_Address;  			// adres docelowy transferu
  DMA_InitStructure.DMA_MemoryBaseAddr = (uint32_t) PC2_adc;            			// adres poczatku bloku do przeslania
  DMA_InitStructure.DMA_DIR = DMA_DIR_PeripheralSRC;                          // kierunek transferu
  DMA_InitStructure.DMA_BufferSize = 100;                                     // liczba elementow do przeslania (dlugosc bufora)
  DMA_InitStructure.DMA_PeripheralInc = DMA_PeripheralInc_Disable;            // wylaczenie autoinkrementacji adresu po stronie ADC
  DMA_InitStructure.DMA_MemoryInc = DMA_MemoryInc_Enable;                     // wlaczenie autoinkrementacji adresu po stronie pamieci (bufora)
  DMA_InitStructure.DMA_PeripheralDataSize = DMA_PeripheralDataSize_HalfWord;	// rozmiar pojedynczych przesylanych danych po stronie ADC (HalfWord = 16bit)
  DMA_InitStructure.DMA_MemoryDataSize = DMA_MemoryDataSize_HalfWord;         // rozmiar pojedynczych przesylanych danych po stronie pamieci (bufora) = 16bit
  DMA_InitStructure.DMA_Mode = DMA_Mode_Circular;                             // tryb dzialania kontrolera DMA - powtarzanie cykliczne
  DMA_InitStructure.DMA_Priority = DMA_Priority_High;                         // priorytet DMA - wysoki
  DMA_InitStructure.DMA_M2M = DMA_M2M_Disable;                                // wylaczenie obslugi transferu z pamieci do pamieci
  DMA_Init(DMA1_Channel1, &DMA_InitStructure);                                // zapis konfiguracji
  DMA_Cmd(DMA1_Channel1, ENABLE);		//Wlacz DMA, kanal 1
}
// ------------------ opoznienie programowe -------------------
void Delay(unsigned int counter){
	// opoznienie programowe, 8'000'000 to jedna sekunda
	while (counter--){
		__NOP();
		__NOP();
	}
}
/**************** (C) COPYRIGHT 2016 PLUMicroelectronics *****END OF FILE******/




