/******************************************************
 *  Systemy Mikroprocesorowe w Sterowaniu,  WEiTI PW 	*
 *  STM3210E-EVAL:  PROJEKT_29 regulator PI						*
 *       gniazdo BNC-CN5 -> PC1 wejscie - zaklocenia	*
 *       gniazdo BNC-CN3 -> PC2 y(t) regulowane				*
 *			 gniazdo BNC-CN2 <- PA4 u(t) sterowanie				*
 *       potencjometr    -> Yzad = wartosc zadana			*
 ******************************************************/
#include "stm32f10x.h"
#include "stm3210e_eval_lcd.h"
#include <stdio.h>
#define Brown 0xEBC2
#define Amber 0xFDEA

#define Ts 	 0.05		// okres probkowania 50 ms
#define Kp	 0.75
#define Ti	 5.0  	
/*
#define Kp	 1.38		// obiekt inercyjny
#define Ti	10.0
*/

int  RCC_Config(void);
void GPIO_Config(void);
void NVIC_Config(void);
void ADC_Config(void);
void DAC_Config(void);
int SysTick_Config_Div8(unsigned int Ticks);
void Delay(unsigned int);

// zmienne globalne -------------------------------------------
unsigned char txt2LCD[20] = {0}; 	// bufor funkcji sprintf
unsigned int k = 0; 							// licznik do wyswietlania
float Fi = 0.0;										// PI
int u_bin = 0;
// stale globalne
const float K = Kp;								// K
const float TsKTi = Ts*Kp/Ti;			// Ts * K / Ti

int main(void) {
  //------------------- deklaracje zmiennych ------------------
	
  //konfiguracja systemu --------------------------------------
  RCC_Config();		
  GPIO_Config();
	NVIC_Config();
	ADC_Config();						// inicjalizacja ADC1
	DAC_Config(); 					// inicjalizacja DAC
	STM3210E_LCD_Init();		// inicjalizacja TFT LCD 240320L8
  GPIO_ResetBits(GPIOF, GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9);	// zgasimy wszystkie diody LED
	LCD_Clear(Black);		// Clear the LCD
  LCD_SetBackColor(Black);		// kolor tla
	LCD_SetFont(&Font16x24);
	ADC_SoftwareStartConvCmd(ADC1, ENABLE); // rozpocznij przetwarzanie ADC1
	ADC_SoftwareStartConvCmd(ADC2, ENABLE); // rozpocznij przetwarzanie ADC2
	ADC_SoftwareStartConvCmd(ADC3, ENABLE); // rozpocznij przetwarzanie ADC3
	while (!ADC_GetFlagStatus(ADC1,ADC_FLAG_EOC));	// czekamy na zakonczenie konwersji
	while (!ADC_GetFlagStatus(ADC2,ADC_FLAG_EOC));	// czekamy na zakonczenie konwersji
	while (!ADC_GetFlagStatus(ADC3,ADC_FLAG_EOC));	// czekamy na zakonczenie konwersji
	SysTick_Config_Div8(450000ul);	// przerwanie co 0.05 sekundy

	while(1);
}
//------------ konfiguracja RCC: sygnaly taktujace ------------
int RCC_Config(void) {
  ErrorStatus HSEStartUpStatus;                          // zmienna opisujaca rezultat uruchomienia HSE

  RCC_DeInit();                                          // RCC na 'default reset state'
  RCC_HSEConfig(RCC_HSE_ON);                             // wlacz HSE
  HSEStartUpStatus = RCC_WaitForHSEStartUp();            // czekaj na gotowosc HSE
  if(HSEStartUpStatus == SUCCESS) {
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);//
    FLASH_SetLatency(FLASH_Latency_2);                   // zwloka Flasha: 2 takty dla 72MHz
    RCC_HCLKConfig(RCC_SYSCLK_Div1);                     // HCLK=SYSCLK
    RCC_PCLK2Config(RCC_HCLK_Div1);                      // PCLK2=HCLK
    RCC_PCLK1Config(RCC_HCLK_Div2);                      // PCLK1=HCLK/2
    RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9); // PLLCLK = HSE*9 czyli 8MHz * 9 = 72 MHz
    RCC_PLLCmd(ENABLE);                                  // wlacz PLL
    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);  // czekaj na uruchomienie PLL
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);           // ustaw PLL jako zrodlo sygnalu zegarowego
    while(RCC_GetSYSCLKSource() != 0x08);                // czekaj az PLL bedzie sygnalem zegarowym systemu
// konfiguracja sygnalow taktujacych uzywanych peryferii
		RCC_ADCCLKConfig(RCC_PCLK2_Div6);                    // ADCCLK = PCLK2/6 = 72 MHz /6 = 12 MHz
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1, ENABLE); // wlacz taktowanie ADC1
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC2, ENABLE); // wlacz taktowanie ADC2
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC3, ENABLE); // wlacz taktowanie ADC3
		RCC_APB1PeriphClockCmd(RCC_APB1Periph_DAC, ENABLE);  // wlacz taktowanie DAC
    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOF, ENABLE);// port GPIO F : LEDy
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);// port GPIO C : PC1 = wejscie analogowe
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOA, ENABLE);// port GPIO A : PA4 = wyjscie analogowe
		return 0;
  }
	else
		return 1;
}
//------------------ konfiguracja portow GPIO -----------------
void GPIO_Config(void) {
  GPIO_InitTypeDef  GPIO_InitStructure; 

  /*Tu nalezy umiescic kod zwiazany z konfiguracja poszczegolnych portow GPIO potrzebnych w programie*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP;      // wyjscie w trybie push-pull
  GPIO_Init(GPIOF, &GPIO_InitStructure);
	
	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_1 | GPIO_Pin_2 | GPIO_Pin_4;	//	wejscia analogowe:
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;						// 		z gniazda BNC-CN5 -> PC1
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;				// 		z gniazda BNC-CN3 -> PC2
  GPIO_Init(GPIOC, &GPIO_InitStructure);									//    potencjometr
	
	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_4;      //	wyjscie analogowe z gniazda BNC-CN5 <- PA4
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AF_PP;	// Alternate function output Push-Pull
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOA, &GPIO_InitStructure);
}
// ----------- konfiguracja kontrolera przerwan NVIC ----------
void NVIC_Config(void) {
  NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);   
}
// --------- konfiguracja licznika systemowego SysTick --------
int SysTick_Config_Div8(unsigned int Ticks){ 
  unsigned int ctrl;

  if (Ticks > SysTick_LOAD_RELOAD_Msk)  return 1;             	// czy wartosc poczatkowa nie przekracza max
                                                                
  SysTick->LOAD = (Ticks & SysTick_LOAD_RELOAD_Msk) - 1;        // ustaw wartosc poczatkowa licznika 
  NVIC_SetPriority (SysTick_IRQn, 0);                           // ustaw priorytet przerwania
  SysTick->VAL  = 0;                                            // ustaw wartosc aktualna licznika
  ctrl=SysTick_CTRL_TICKINT_Msk | SysTick_CTRL_ENABLE_Msk;      // ustaw flagi wlaczenia SysTick IRQ  i samego licznika
	ctrl &= SysTick_CLKSource_HCLK_Div8;
  SysTick->CTRL = ctrl;                  // zapisz ustawienia do rejestru sterujacego SysTick (i wlacz licznik)
  return 0;
}
// ------------ konfiguracja przetwornika ADC1/2/3 ------------
void ADC_Config(void){
  ADC_InitTypeDef ADC_InitStructure;
	  
	ADC_InitStructure.ADC_Mode = ADC_Mode_Independent;                  // praca niezalezna
	ADC_InitStructure.ADC_ScanConvMode = DISABLE;                       // pomiar jednego kanalu, skanowanie kanalow nie potrzebne
  ADC_InitStructure.ADC_ContinuousConvMode = DISABLE;               	// pomiar w trybie jednokrotnym
  //ADC_InitStructure.ADC_ContinuousConvMode = ENABLE;                  // pomiar w trybie ciaglym
	ADC_InitStructure.ADC_ExternalTrigConv = ADC_ExternalTrigConv_None;	// brak wyzwalania zewnetrznego
	ADC_InitStructure.ADC_DataAlign = ADC_DataAlign_Right;            	// wyrownanie danych do prawej - 12 mlodszych bitow znaczacych
	ADC_InitStructure.ADC_NbrOfChannel = 1; 	                          // liczba uzywanych kanalow =1
	ADC_Init(ADC1, &ADC_InitStructure);                                 // incjalizacja przetwornika ADC1
	ADC_Init(ADC2, &ADC_InitStructure);                                 // incjalizacja przetwornika ADC2
	ADC_Init(ADC3, &ADC_InitStructure);                                 // incjalizacja przetwornika ADC3
	ADC_Cmd(ADC1, ENABLE);                                              // wlacz ADC1
	ADC_Cmd(ADC2, ENABLE);                                              // wlacz ADC2
	ADC_Cmd(ADC3, ENABLE);                                              // wlacz ADC3
	
	ADC_ResetCalibration(ADC1);                                         // reset rejestrow kalibracyjnych ADC1
	while(ADC_GetResetCalibrationStatus(ADC1));                         // czekamy na wykonanie resetu
	ADC_StartCalibration(ADC1);                                         // kalibracja ADC1
	while(ADC_GetCalibrationStatus(ADC1));                              // czekamy na zakonczenie kalibracji ADC1
	
	ADC_ResetCalibration(ADC2);                                         // reset rejestrow kalibracyjnych ADC2
	while(ADC_GetResetCalibrationStatus(ADC2));                         // czekamy na wykonanie resetu
	ADC_StartCalibration(ADC2);                                         // kalibracja ADC2
	while(ADC_GetCalibrationStatus(ADC2));                              // czekamy na zakonczenie kalibracji ADC2
	
	ADC_ResetCalibration(ADC3);                                         // reset rejestrow kalibracyjnych ADC3
	while(ADC_GetResetCalibrationStatus(ADC3));                         // czekamy na wykonanie resetu
	ADC_StartCalibration(ADC3);                                         // kalibracja ADC3
	while(ADC_GetCalibrationStatus(ADC3));                              // czekamy na zakonczenie kalibracji ADC3
	
	ADC_RegularChannelConfig(ADC1, ADC_Channel_12, 1, ADC_SampleTime_1Cycles5);
																																			// kanal 12 - GPIO-PC2 - BNC-CN3
                                                                      // grupa podstawowa, czas probkowania 1,5 + 12,5 = 14 cykli
	ADC_RegularChannelConfig(ADC2, ADC_Channel_14, 1, ADC_SampleTime_1Cycles5); 
																																			// kanal 14 - GPIO-PC4 - potencjometr
                                                                      // grupa podstawowa, czas probkowania 1,5 + 12,5 = 14 cykli

	ADC_RegularChannelConfig(ADC3, ADC_Channel_11, 1, ADC_SampleTime_1Cycles5); 
                                                                      // kanal 11 - GPIO-PC1 - BNC-CN5
                                                                      // grupa podstawowa, czas probkowania 1,5 + 12,5 = 14 cykli                                                            
}
// --------- konfiguracja przetwornika DAC channel1 -----------
void DAC_Config(void){
	DAC_InitTypeDef DAC_InitStructure;
	
	DAC_InitStructure.DAC_Trigger = DAC_Trigger_None;										// nie jest wyzwalany zewnetrznie, tylko przez wpis do rejestru
  DAC_InitStructure.DAC_WaveGeneration = DAC_WaveGeneration_None;			// bez generowania ...
  DAC_InitStructure.DAC_LFSRUnmask_TriangleAmplitude = DAC_LFSRUnmask_Bit0; // nie uzywane
  DAC_InitStructure.DAC_OutputBuffer = DAC_OutputBuffer_Enable;				// bufor zezwolony
	DAC_Init(DAC_Channel_1, &DAC_InitStructure);                        // incjalizacja przetwornika
	
	DAC_Cmd(DAC_Channel_1, ENABLE);                                     // wlacz DAC Channel1
}
// ------------------ opoznienie programowe -------------------
void Delay(unsigned int counter){
	// opoznienie programowe, 8'000'000 to jedna sekunda
	while (counter--){
		__NOP();
		__NOP();
	}
}
/**************** (C) COPYRIGHT 2016 PLUMicroelectronics *****END OF FILE******/




