/**************************************************************
 *  Systemy Mikroprocesorowe w Sterowaniu,  WEiTI PW 					*
 *  STM3210E-EVAL: PROJEKT32 MultiTasking											*
 **************************************************************/
#include "stm32f10x.h"
#include "stm3210e_eval_lcd.h"
#include <stdio.h>
#include "AsmCode.h"
#include "Task1.h"
#include "Task2.h"

// prototypy funkcji ------------------------------------------
int  RCC_Config(void);
void GPIO_Config(void);
void NVIC_Config(void);
void ADC_Config(void);
int SysTick_Config_Div8(unsigned int Ticks);
void Delay(unsigned int);
// prototypy funkcji systemowych RTOS -------------------------
void new_task(void (*func)(void*), uint32_t);
void update_sp(void);
uint32_t get_next_task(void);

// zmienne globalne -------------------------------------------
unsigned char txt2LCD[20] = {0}; 	// bufor funkcji sprintf
unsigned int counter_main = 0;
unsigned int counter_task1 = 0;
unsigned int counter_task2 = 0;
unsigned int current_task = 0; 	// numer biezacego tasku
float voltage;									// napiecie potencjometru (Task1)

task_table_t task_table[3];			// tablica taskow
																// task_table[0]: stack of the main task
																// task_table[1]: stack of task1
																// task_table[2]: stack of task2
// tablice parametrow inicjujacych taski ----------------------
const uint32_t var1 = 2, var2 = 3;

// MAIN-TASK --------------------------------------------------
int main(void) {
  //------------------- deklaracje zmiennych ------------------
	volatile unsigned int k;
	
  //konfiguracja systemu --------------------------------------
  RCC_Config();		
  GPIO_Config();
	NVIC_Config();
	ADC_Config();						// inicjalizacja ADC1
	STM3210E_LCD_Init();		// inicjalizacja TFT LCD 240320L8
  GPIO_ResetBits(GPIOF, GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9);	// zgasimy wszystkie diody LED
	LCD_Clear(Black);		// Clear the LCD
  LCD_SetBackColor(Black);		// kolor tla
	LCD_SetFont(&Font16x24);
	ADC_SoftwareStartConvCmd(ADC1, ENABLE); // rozpocznij przetwarzanie ADC
	while (!ADC_GetFlagStatus(ADC1,ADC_FLAG_EOC));	// czekamy na zakonczenie konwersji
	
	// inicjalizacja Multitasking
	task_table[1].sp = (unsigned int) 0x20001700;
	task_table[2].sp = (unsigned int) 0x20002700;
	new_task(my_task_1, (uint32_t) &var1); 	// inicjalizuje Task1, ze wskaznikiem na tablice parametrow
	new_task(my_task_2, (uint32_t) &var2); 	// inicjalizuje Task2, ze wskaznikiem na tablice parametrow
	
	SysTick_Config_Div8(450000ul);	// przerwanie co 0.05 sekundy
	
	while(1){
		counter_main ++;							// toggle LED zielony
		GPIO_WriteBit(GPIOF, GPIO_Pin_6, (BitAction)(1-GPIO_ReadOutputDataBit(GPIOF, GPIO_Pin_6)));
		LCD_SetTextColor(Green);   // kolor textu
		sprintf((char *)txt2LCD," main  = %i",counter_main);
		LCD_DisplayStringLine(Line1, (uint8_t *)txt2LCD);
		LCD_SetTextColor(Red);   	// kolor textu
		sprintf((char *)txt2LCD," task1 = %i",counter_task1);
		LCD_DisplayStringLine(Line3, (uint8_t *)txt2LCD);
		sprintf((char *)txt2LCD,"     U = %3.2f [V]",voltage);
		LCD_DisplayStringLine(Line4, (uint8_t *)txt2LCD);
		LCD_SetTextColor(Blue);   // kolor textu
		sprintf((char *)txt2LCD," task2 = %i",counter_task2);
		LCD_DisplayStringLine(Line6, (uint8_t *)txt2LCD);
		for(k=0; k<100000; k++);
	}
}
//------------ konfiguracja RCC: sygnaly taktujace ------------
int RCC_Config(void) {
  ErrorStatus HSEStartUpStatus;                          // zmienna opisujaca rezultat uruchomienia HSE

  RCC_DeInit();                                          // RCC na 'default reset state'
  RCC_HSEConfig(RCC_HSE_ON);                             // wlacz HSE
  HSEStartUpStatus = RCC_WaitForHSEStartUp();            // czekaj na gotowosc HSE
  if(HSEStartUpStatus == SUCCESS) {
    FLASH_PrefetchBufferCmd(FLASH_PrefetchBuffer_Enable);//
    FLASH_SetLatency(FLASH_Latency_2);                   // zwloka Flasha: 2 takty dla 72MHz
    RCC_HCLKConfig(RCC_SYSCLK_Div1);                     // HCLK=SYSCLK
    RCC_PCLK2Config(RCC_HCLK_Div1);                      // PCLK2=HCLK
    RCC_PCLK1Config(RCC_HCLK_Div2);                      // PCLK1=HCLK/2
    RCC_PLLConfig(RCC_PLLSource_HSE_Div1, RCC_PLLMul_9); // PLLCLK = HSE*9 czyli 8MHz * 9 = 72 MHz
    RCC_PLLCmd(ENABLE);                                  // wlacz PLL
    while(RCC_GetFlagStatus(RCC_FLAG_PLLRDY) == RESET);  // czekaj na uruchomienie PLL
    RCC_SYSCLKConfig(RCC_SYSCLKSource_PLLCLK);           // ustaw PLL jako zrodlo sygnalu zegarowego
    while(RCC_GetSYSCLKSource() != 0x08);                // czekaj az PLL bedzie sygnalem zegarowym systemu
// konfiguracja sygnalow taktujacych uzywanych peryferii
		RCC_ADCCLKConfig(RCC_PCLK2_Div6);                    // ADCCLK = PCLK2/6 = 72 MHz /6 = 12 MHz
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_ADC1, ENABLE); // wlacz taktowanie ADC1
    RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOF, ENABLE);// port GPIO F : LEDy
		RCC_APB2PeriphClockCmd(RCC_APB2Periph_GPIOC, ENABLE);// port GPIO C : PC4 = wejscie analogowe
		return 0;
  }
	else
		return 1;
}
//------------------ konfiguracja portow GPIO -----------------
void GPIO_Config(void) {
  GPIO_InitTypeDef  GPIO_InitStructure; 

  /*Tu nalezy umiescic kod zwiazany z konfiguracja poszczegolnych portow GPIO potrzebnych w programie*/
  GPIO_InitStructure.GPIO_Pin = GPIO_Pin_6 | GPIO_Pin_7 | GPIO_Pin_8 | GPIO_Pin_9;
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_2MHz;
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_Out_PP; 	// wyjscie w trybie push-pull
  GPIO_Init(GPIOF, &GPIO_InitStructure);
	
	GPIO_InitStructure.GPIO_Pin =  GPIO_Pin_4;   
  GPIO_InitStructure.GPIO_Mode = GPIO_Mode_AIN;			//	wejscie analogowe z potencjometru
  GPIO_InitStructure.GPIO_Speed = GPIO_Speed_50MHz;
  GPIO_Init(GPIOC, &GPIO_InitStructure);
}
// ----------- konfiguracja kontrolera przerwan NVIC ----------
void NVIC_Config(void) {
  NVIC_SetVectorTable(NVIC_VectTab_FLASH, 0x0);   
}
// --------- konfiguracja licznika systemowego SysTick --------
int SysTick_Config_Div8(unsigned int Ticks){ 
  unsigned int ctrl;

  if (Ticks > SysTick_LOAD_RELOAD_Msk)  return 1;             	// czy wartosc poczatkowa nie przekracza max
                                                                
  SysTick->LOAD = (Ticks & SysTick_LOAD_RELOAD_Msk) - 1;        // ustaw wartosc poczatkowa licznika 
  NVIC_SetPriority (SysTick_IRQn, 0);                           // ustaw priorytet przerwania
  SysTick->VAL  = 0;                                            // ustaw wartosc aktualna licznika
  ctrl=SysTick_CTRL_TICKINT_Msk | SysTick_CTRL_ENABLE_Msk;      // ustaw flagi wlaczenia SysTick IRQ  i samego licznika
	ctrl &= SysTick_CLKSource_HCLK_Div8;
  SysTick->CTRL = ctrl;                  // zapisz ustawienia do rejestru sterujacego SysTick (i wlacz licznik)
  return 0;
}
// -------------- konfiguracja przetwornika ADC1 --------------
void ADC_Config(void){
  ADC_InitTypeDef ADC_InitStructure;
	  
	ADC_InitStructure.ADC_Mode = ADC_Mode_Independent;                  // praca niezalezna
	ADC_InitStructure.ADC_ScanConvMode = DISABLE;                       // pomiar jednego kanalu, skanowanie kanalow nie potrzebne
  ADC_InitStructure.ADC_ContinuousConvMode = DISABLE;               	// pomiar w trybie jednokrotnym
	ADC_InitStructure.ADC_ExternalTrigConv = ADC_ExternalTrigConv_None;	// brak wyzwalania zewnetrznego
	ADC_InitStructure.ADC_DataAlign = ADC_DataAlign_Right;            	// wyrownanie danych do prawej - 12 mlodszych bitow znaczacych
	ADC_InitStructure.ADC_NbrOfChannel = 1; 	                          // liczba uzywanych kanalow =1
	ADC_Init(ADC1, &ADC_InitStructure);                                 // incjalizacja przetwornika ADC1
	ADC_Cmd(ADC1, ENABLE);                                              // wlacz ADC1
	
	ADC_ResetCalibration(ADC1);                                         // reset rejestrow kalibracyjnych ADC1
	while(ADC_GetResetCalibrationStatus(ADC1));                         // czekamy na wykonanie resetu
	ADC_StartCalibration(ADC1);                                         // kalibracja ADC1
	while(ADC_GetCalibrationStatus(ADC1));                              // czekamy na zakonczenie kalibracji ADC1
	ADC_RegularChannelConfig(ADC1, ADC_Channel_14, 1, ADC_SampleTime_1Cycles5); 
																																			// kanal 14 - GPIO-PC4 - potencjometr
                                                                      // grupa podstawowa, czas probkowania 1,5 + 12,5 = 14 cykli                                                          
}
// ------------------ opoznienie programowe -------------------
void Delay(unsigned int counter){
	// opoznienie programowe, 8'000'000 to jedna sekunda
	while (counter--){
		__NOP();
		__NOP();
	}
}
/**************************************************************
 * Funkcje systemu RTOS																				*
 **************************************************************/
void new_task(void (*func)(void*), uint32_t args){
	volatile unsigned int i;
	stack_frame_t * frame;
	
	for(i=1; i < MAX_TASKS; i++){
		if(task_table[i].flags == 0){
			frame = (stack_frame_t *)(task_table[i].sp - sizeof(stack_frame_t));
			frame -> r4  = 0;
			frame -> r5  = 0;
			frame -> r6  = 0;
			frame -> r7  = 0;
			frame -> r8  = 0;
			frame -> r9  = 0;
			frame -> r10 = 0;
			frame -> r11 = 0;
			frame -> r0  = (uint32_t)args;
			frame -> r1  = 0;
			frame -> r2  = 0;
			frame -> r3  = 0;
			frame -> r12 = 0;
			frame -> pc  = ((uint32_t)func);
			frame -> lr  = 0;
			frame -> psr = 0x21000000;	// set default PSR value
			task_table[i].flags = TASK_FLAG_EXEC | TASK_FLAG_INIT;
			task_table[i].sp = (uint32_t) frame;
			set_PSP(task_table[i].sp);
			break;
		}
	}
}
// update the stack table
void update_sp(void){
	// save the current task's stack pointer
	if(current_task == 0){
		task_table[current_task].sp = get_MSP();
	}
	else if ((task_table[current_task].flags & TASK_FLAG_EXEC) == 0){
		task_table[current_task].sp = get_PSP();
	}
}
// identify the next task to be executed
uint32_t get_next_task(void){
	current_task ++;
	if(current_task == MAX_TASKS){
		current_task = 0;
		set_MSP(task_table[current_task].sp);
		return 0xFFFFFFF9;	// exit interrupt by using the main stack
	}
	else if(task_table[current_task].flags & TASK_FLAG_INIT){
		set_PSP(task_table[current_task].sp);
		if(task_table[current_task].flags & TASK_FLAG_EXEC)
			task_table[current_task].flags &= ~TASK_FLAG_EXEC;
		return 0xFFFFFFFD;	// exit interrupt by using the process stack
	}
	current_task = 0;			// proba zalaczenia niezainicjowanego tasku
	set_MSP(task_table[current_task].sp);
	return 0xFFFFFFF9;
}
// ---------- Report HardFault when things goes wrong ---------
void HardFault_Handler_C(unsigned int * svc_args){
	LCD_Clear(Blue);		// Clear the LCD
  LCD_SetBackColor(Blue);		// kolor tla
	LCD_SetFont(&Font16x24);
	LCD_SetTextColor(White);   // kolor textu
	sprintf((char *)txt2LCD,"HardFault:");
	LCD_DisplayStringLine(Line0, (uint8_t *)txt2LCD);
	
  sprintf((char *)txt2LCD," curr_task = %d", current_task);
	LCD_DisplayStringLine(Line1, (uint8_t *)txt2LCD);
	
	sprintf((char *)txt2LCD,"task1:SP= %X", task_table[1].sp);
	LCD_DisplayStringLine(Line2, (uint8_t *)txt2LCD);
	sprintf((char *)txt2LCD,"task2:SP= %X", task_table[2].sp);
	LCD_DisplayStringLine(Line3, (uint8_t *)txt2LCD);
	
	sprintf((char *)txt2LCD,"MSP= %X", get_MSP());
	LCD_DisplayStringLine(Line5, (uint8_t *)txt2LCD);
	sprintf((char *)txt2LCD,"PSP= %X", get_PSP());
	LCD_DisplayStringLine(Line6, (uint8_t *)txt2LCD);
	
	sprintf((char *)txt2LCD,"ret_addr= %8.8X", get_return_addr());
	LCD_DisplayStringLine(Line8, (uint8_t *)txt2LCD);
	
  while(1);	// stop CPU
}
/**************** (C) COPYRIGHT 2016 PLUMicroelectronics *****END OF FILE******/


